@@ -7,7 +7,7 @@
 package Lingua::Interset::Tagset::Conll;
 use strict;
 use warnings;
-our $VERSION = '2.037';
+our $VERSION = '2.038';
 
 use utf8;
 use open ':utf8';
@@ -78,7 +78,7 @@ sub decode_conll
     my %features_conll;
     foreach my $f (@features_conll)
     {
-        if($f =~ m/^(\w+)$delimiter(.+)$/)
+        if($f =~ m/^([-\w]+)$delimiter(.+)$/)
         {
             $features_conll{$1} = $2;
         }
@@ -164,7 +164,7 @@ Lingua::Interset::Tagset::Conll - Common code for drivers of tagsets from files
 
 =head1 VERSION
 
-version 2.037
+version 2.038
 
 =head1 DESCRIPTION
 
